@@ -26,15 +26,16 @@ pub struct CtrlPortDemo {
 }
 
 impl CtrlPortDemo {
+    #[allow(clippy::new_ret_no_self)]
     pub fn new() -> Block {
         Block::new_async(
             BlockMetaBuilder::new("CtrlPortDemo").build(),
             StreamIoBuilder::new().build(),
             MessageIoBuilder::new()
-                .register_output("out")
-                .register_sync_input("in", CtrlPortDemo::handler)
+                .add_output("out")
+                .add_sync_input("in", Self::handler)
                 .build(),
-            CtrlPortDemo { counter: 5 },
+            Self { counter: 5 },
         )
     }
 
