@@ -15,9 +15,7 @@ fn main() -> Result<()> {
     let n_items = 20_000;
     let n_copy = 1000;
 
-    let orig: Vec<f32> = repeat_with(|| rand::random::<f32>())
-        .take(n_items)
-        .collect();
+    let orig: Vec<f32> = repeat_with(rand::random::<f32>).take(n_items).collect();
 
     let src = fg.add_block(VectorSourceBuilder::new(orig.clone()).build());
     let snk = fg.add_block(
@@ -51,7 +49,7 @@ fn main() -> Result<()> {
 
     assert_eq!(v.len(), n_items);
     for i in 0..v.len() {
-        assert_eq!(orig[i], v[i]);
+        assert!((orig[i] - v[i]).abs() < f32::EPSILON);
     }
 
     println!("flowgraph took {:?}", elapsed);
